function [ syntheticData, assignments, T ] = generateSyntheticDataCosineNorm( referenceData, numberOfRegions, numberOfPixels, dataSelection)
%generateSyntheticDataCosineNorm Generates synthetic dataset by
%statistical modelling of the input reference data as a series of Euclidean
%normally distributed datasets

%Uses reference data that is Euclidean normally distributed

%Input:
%   referenceData is an input cell containing matrices of the reference data to be modelled
%   numberOfRegions is an integer value for the number of synthetic data regions to be generated, must be < number of reference data cells
%   numberOfPixels is a vector of number of pixels to be generated for each of the regions
%   dataSelection either Random or ordered determines whether to sample from the reference data in a random order or sequentially

%Output:
%   syntheticData is a cell of matrices each containing the number of pixels specified by the variable numberOfPixels
%   assignments are a reference to the corresponding datasets used for statistical modelling if the random dataSelection is used
%   specifying T supplies the Cholesky factor, which can be used for future synthetic data for improved efficiency (see generateSyntheticDataFromCholcovCosines)


%% Setup sizes of cells
syntheticData = cell(numberOfRegions,1);
T = cell(numberOfRegions,1);
polarData = cell(length(referenceData),1);
polarHypotenuse = cell(length(referenceData),1);
polarCovariances = cell(length(referenceData),1);
polarMeans = cell(length(referenceData),1);
hypotenuseMeans = cell(length(referenceData),1);
hypotenuseStandardDeviations = cell(length(referenceData),1);
%% Convert data to polar co-ordinates and get means and varainces
for i = 1:length(referenceData);
    [polarData{i}, polarHypotenuse{i}] = Cart2polD(referenceData{i});    %convert real data to polar co-ordiantes
    polarData{i}(isnan(polarData{i})) = 0; %remove NaNs created in polar conversion
    polarCovariances{i} = cov(polarData{i});    %determine covariance
    polarMeans{i} = mean(polarData{i});    %determine mean
    hypotenuseMeans{i} = mean(polarHypotenuse{i});    %determine the hypotenuse mean
    hypotenuseStandardDeviations{i} = std(polarHypotenuse{i});      %determine the hypotenuse standard deviation
end

%% Setup synthetic data from real data
if nargin>3
    if strcmp(dataSelection, 'Random')
        assignments = randperm(length(referenceData), numberOfRegions); %determine random antamical regions to get the data from
    else
        assignments = 1:numberOfRegions;
    end
else
    assignments = 1:numberOfRegions;
end
for i = 1:numberOfRegions;
    c = assignments(i); %store the assignment used in each instance
    [polarSynthetic, T{i}] = mvnrnd(polarMeans{c}, polarCovariances{c}, numberOfPixels(i)); %set up multivariate normal polar data with mean and covariance of the real data
    hypotenuseSynthetic = abs(randn(numberOfPixels(i),1).*hypotenuseStandardDeviations{c} + hypotenuseMeans{c});    %set up normally distribiuted hypotenuse with mean and standard deviatin of the real data
    syntheticData{i} = Pol2CartD(hypotenuseSynthetic, polarSynthetic); %convert the data back to cartesian co-ordinates
    syntheticData{i} = abs(syntheticData{i}); %removes negatives which are not observed in mass spectrometry imaging 
end
end

