function [ syntheticData, assignments ] = generateSyntheticDataEuclideanNorm( referenceData, numberOfRegions, numberOfPixels, dataSelection)
%generateSyntheticDataEuclideanNorm Generates synthetic dataset by
%statistical modelling of the input reference data as a series of Euclidean
%normally distributed datasets

%Uses reference data that is Euclidean normally distributed

%Input:
%   referenceData is an input cell containing matrices of the reference data to be modelled
%   numberOfRegions is an integer value for the number of synthetic data regions to be generated, must be < number of reference data cells
%   numberOfPixels is a vector of number of pixels to be generated for each of the regions
%   dataSelection either Random or ordered determines whether to sample from the reference data in a random order or sequentially

%Output:
%   syntheticData is a cell of matrices each containing the number of pixels specified by the variable numberOfPixels
%   assignments are a reference to the corresponding datasets used for statistical modelling if the random dataSelection is used
%   specifying T supplies the Cholesky factor, which can be used for future synthetic data for improved efficiency (see generateSyntheticDataFromCholcovEuclidean)

%% Setup sizes of cells
syntheticData = cell(numberOfRegions,1);
dataMeans = cell(numberOfRegions,1);
dataCovariances = cell(numberOfRegions,1);
T = cell(numberOfRegions,1);
%% Convert data to polar co-ordinates and get means and varainces
for i = 1:length(referenceData);
    dataMeans{i} = mean(referenceData{i});
    dataCovariances{i} = cov(referenceData{i});
end

%% Setup synthetic data from real data
if nargin>3
    if strcmp(dataSelection, 'Random')
        assignments = randperm(length(referenceData), numberOfRegions); %determine random antamical regions to get the data from
    else
        assignments = 1:numberOfRegions;
    end
else
    assignments = 1:numberOfRegions;
end

for i = 1:numberOfRegions;
    c = assignments(i); %store the assignment used in each instance
    [syntheticData{i}, T{i}] = mvnrnd(dataMeans{c}, dataCovariances{c}, numberOfPixels(i)); %set up multivariate normal data with mean and covariance of the real data
    syntheticData{i} = abs(syntheticData{i}); %removes negatives not observed in MSI
end

end

